var react = require('react');

var useAsyncLoading = function useAsyncLoading(defaultValue) {
  if (defaultValue === void 0) {
    defaultValue = false;
  }
  var _useState = react.useState(defaultValue),
    loading = _useState[0],
    updateLoading = _useState[1];
  var enable = react.useCallback(function () {
    return updateLoading(true);
  }, []);
  var disable = react.useCallback(function () {
    return updateLoading(false);
  }, []);
  var toggle = react.useCallback(function () {
    return updateLoading(function (state) {
      return !state;
    });
  }, []);
  var registerPromise = react.useCallback(function (promise) {
    try {
      enable();
      return Promise.resolve(promise["finally"](disable));
    } catch (e) {
      return Promise.reject(e);
    }
  }, [enable, disable]);
  return [loading, {
    registerPromise: registerPromise,
    toggle: toggle,
    update: updateLoading,
    disable: disable,
    enable: enable
  }];
};

exports.useAsyncLoading = useAsyncLoading;
//# sourceMappingURL=index.js.map
